# myADS

## Installation

### From source

To install from source:

* Clone the repository using ``git clone https://github.com/stuartmcalpine/myADS.git``
* Navigate to the ``myADS`` folder
* Install using `pip install .`

## Keep track of your citations

## Simple ADS API query package
